@@ -26,11 +26,11 @@
  *
  * ============================================================ */
 
-// Local includes.
+// Local includes
 #include "ksane_widget_private.h"
 #include "ksane_widget_private.moc"
 
-// Qt includes.
+// Qt includes
 #include <QImage>
 #include <QScrollArea>
 #include <QScrollBar>
@@ -157,7 +157,7 @@ void KSaneWidgetPrivate::devListUpdated()
 
 void KSaneWidgetPrivate::signalDevListUpdate()
 {
-    emit q->availableDevices(m_findDevThread->devicesList());
+    emit (q->availableDevices(m_findDevThread->devicesList()));
 }
 
 KSaneWidget::ImageFormat KSaneWidgetPrivate::getImgFormat(SANE_Parameters &params)
@@ -807,7 +807,7 @@ void KSaneWidgetPrivate::previewScanDone()
         sane_close(m_saneHandle);
         m_saneHandle = 0;
         clearDeviceOptions();
-        emit q->scanDone(KSaneWidget::NoError, "");
+        emit (q->scanDone(KSaneWidget::NoError, ""));
         return;
     }
 
@@ -833,7 +833,7 @@ void KSaneWidgetPrivate::previewScanDone()
     
     m_previewViewer->updateImage();
     
-    emit q->scanDone(KSaneWidget::NoError, "");
+    emit (q->scanDone(KSaneWidget::NoError, ""));
     
     return;
 }
@@ -905,11 +905,11 @@ void KSaneWidgetPrivate::oneFinalScanDone()
             int bytesPerLine = qMax(getBytesPerLines(params), 1); // ensure no div by 0
             lines = m_scanData.size() / bytesPerLine;
         }
-        emit q->imageReady(m_scanData,
+        emit (q->imageReady(m_scanData,
                          params.pixels_per_line,
                          lines,
                          getBytesPerLines(params),
-                         (int)getImgFormat(params));
+                         (int)getImgFormat(params)));
 
         // now check if we should have automatic ADF batch scaning
         if (m_optSource){
@@ -982,7 +982,7 @@ void KSaneWidgetPrivate::oneFinalScanDone()
                 return;
             }
         }
-        emit q->scanDone(KSaneWidget::NoError, "");
+        emit (q->scanDone(KSaneWidget::NoError, ""));
     }
     else {
         switch(m_scanThread->saneStatus()) 
@@ -992,7 +992,7 @@ void KSaneWidgetPrivate::oneFinalScanDone()
             case SANE_STATUS_EOF:
                 break;
             case SANE_STATUS_NO_DOCS:
-                emit q->scanDone(KSaneWidget::Information, i18n(sane_strstatus(m_scanThread->saneStatus())));
+                emit (q->scanDone(KSaneWidget::Information, i18n(sane_strstatus(m_scanThread->saneStatus()))));
                 alertUser(KSaneWidget::Information, i18n(sane_strstatus(m_scanThread->saneStatus())));
                 break;
             case SANE_STATUS_UNSUPPORTED:
@@ -1003,7 +1003,7 @@ void KSaneWidgetPrivate::oneFinalScanDone()
             case SANE_STATUS_COVER_OPEN:
             case SANE_STATUS_DEVICE_BUSY:
             case SANE_STATUS_ACCESS_DENIED:
-                emit q->scanDone(KSaneWidget::ErrorGeneral, i18n(sane_strstatus(m_scanThread->saneStatus())));
+                emit (q->scanDone(KSaneWidget::ErrorGeneral, i18n(sane_strstatus(m_scanThread->saneStatus()))));
                 alertUser(KSaneWidget::ErrorGeneral, i18n(sane_strstatus(m_scanThread->saneStatus())));
                 break;
         }
@@ -1101,7 +1101,7 @@ void KSaneWidgetPrivate::updateProgress()
     }
     
     m_progressBar->setValue(progress);
-    emit q->scanProgress(progress);
+    emit (q->scanProgress(progress));
 }
 
 void KSaneWidgetPrivate::alertUser(int type, const QString &strStatus)
@@ -1113,10 +1113,11 @@ void KSaneWidgetPrivate::alertUser(int type, const QString &strStatus)
                 break;
             default:
                 KMessageBox::information(0, strStatus);
+                break;
         }
     }
     else {
-        emit q->userMessage(type, strStatus);
+        emit (q->userMessage(type, strStatus));
     }
 }
 
